#[non_exhaustive]pub struct UntagResourceInput {
pub resource_arn: Option<String>,
pub tag_keys: Option<Vec<String>>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.resource_arn: Option<String>Specifies the ARN of the resource from which tags are to be removed.
tag_keys: Option<Vec<String>>A comma-separated list of one or more tag keys whose tags are to be removed from the specified resource.
Implementations
Sourceimpl UntagResourceInput
impl UntagResourceInput
Sourcepub fn resource_arn(&self) -> Option<&str>
pub fn resource_arn(&self) -> Option<&str>
Specifies the ARN of the resource from which tags are to be removed.
Sourceimpl UntagResourceInput
impl UntagResourceInput
Sourcepub fn builder() -> UntagResourceInputBuilder
pub fn builder() -> UntagResourceInputBuilder
Creates a new builder-style object to manufacture UntagResourceInput.